@@ -75,7 +75,6 @@ setMethodS3("rowTabulates", "matrix", function(x, values=NULL, ...) {
   counts <- matrix(0L, nrow=nrow(x), ncol=nbrOfValues);
   colnames(counts) <- names;
 
-  dim <- dim(x);
   for (kk in seq(length=nbrOfValues)) {
     counts[,kk] <- rowCounts(x, value=values[kk], ...);
   }
@@ -85,11 +84,58 @@ setMethodS3("rowTabulates", "matrix", function(x, values=NULL, ...) {
 
 
 setMethodS3("colTabulates", "matrix", function(x, values=NULL, ...) {
-  x <- t(x);
-  counts <- rowTabulates(x, values=values, ...);
-  x <- NULL; # Not needed anymore
-#  if (transpose)
-#    counts <- t(counts);
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # Validate arguments
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # Argument 'x':
+  if (is.integer(x)) {
+  } else if (is.raw(x)) {
+  } else {
+    stop("Argument 'x' is not of type integer or raw: ", class(x)[1]);
+  }
+
+  # Argument 'values':
+  if (is.null(values)) {
+    values <- as.vector(x);
+    values <- unique(values);
+    if (is.raw(values)) {
+      values <- as.integer(values);
+      values <- sort(values);
+      # WORKAROUND: Cannot use "%#x" because it gives an error OSX with
+      # R v2.9.0 devel (2009-01-13 r47593b) at R-forge. /HB 2009-06-20
+      names <- sprintf("%x", values);
+      names <- paste("0x", names, sep="");
+      values <- as.raw(values);
+    } else {
+      values <- sort(values);
+      names <- as.character(values);
+    }
+  } else {
+    if (is.raw(values)) {
+      names <- sprintf("%x", as.integer(values));
+      names <- paste("0x", names, sep="");
+    } else {
+      names <- as.character(values);
+    }
+  }
+
+
+  transpose <- FALSE
+  if (transpose) {
+    nbrOfValues <- length(values);
+    counts <- matrix(0L, nrow=nbrOfValues, ncol=ncol(x));
+    rownames(counts) <- names;
+    for (kk in seq(length=nbrOfValues)) {
+      counts[kk,] <- colCounts(x, value=values[kk], ...);
+    }
+  } else {
+    nbrOfValues <- length(values);
+    counts <- matrix(0L, nrow=ncol(x), ncol=nbrOfValues);
+    colnames(counts) <- names;
+    for (kk in seq(length=nbrOfValues)) {
+      counts[,kk] <- colCounts(x, value=values[kk], ...);
+    }
+  }
   counts;
 })
 
@@ -97,6 +143,8 @@ setMethodS3("colTabulates", "matrix", function(x, values=NULL, ...) {
 
 ############################################################################
 # HISTORY:
+# 2014-11-16
+# o Now colTabulates(x) no longer calls rowTabulates(t(x)).
 # 2014-06-02
 # o Made rowTabulates() an S3 method (was S4).
 # o SPEEDUP: Now rowTabulates() utilizes rowCounts().
