@@ -20,6 +20,8 @@
 #  \item{x}{A @numeric NxK @matrix.}
 #  \item{center}{(optional) The center, defaults to the row means.}
 #  \item{na.rm}{If @TRUE, @NAs are excluded first, otherwise not.}
+#  \item{dim.}{An @integer @vector of length two specifying the
+#              dimension of \code{x}, also when not a @matrix.}
 #  \item{...}{Additional arguments passed to \code{rowMeans()} and
 #     \code{rowSums()}.}
 # }
@@ -41,7 +43,15 @@
 # @keyword robust
 # @keyword univar
 #*/###########################################################################
-rowVars <- function(x, na.rm=TRUE, center=NULL, ...) {
+rowVars <- function(x, na.rm=TRUE, center=NULL, dim.=dim(x), ...) {
+  if (is.null(center)) {
+    dim. <- as.integer(dim.)
+    na.rm <- as.logical(na.rm)
+    hasNAs <- TRUE
+    sigma2 <- .Call("rowVars", x, dim., na.rm, hasNAs, TRUE, PACKAGE="matrixStats");
+    return(sigma2)
+  }
+
   ncol <- ncol(x);
 
   # Nothing to do?
@@ -85,7 +95,15 @@ rowVars <- function(x, na.rm=TRUE, center=NULL, ...) {
 }
 
 
-colVars <- function(x, na.rm=TRUE, center=NULL, ...) {
+colVars <- function(x, na.rm=TRUE, center=NULL, dim.=dim(x), ...) {
+  if (is.null(center)) {
+    dim. <- as.integer(dim.)
+    na.rm <- as.logical(na.rm)
+    hasNAs <- TRUE
+    sigma2 <- .Call("rowVars", x, dim., na.rm, hasNAs, FALSE, PACKAGE="matrixStats");
+    return(sigma2)
+  }
+
   nrow <- nrow(x);
 
   # Nothing to do?
