@@ -12,12 +12,37 @@ colMads_R <- function(x, na.rm=FALSE) {
   })
 }
 
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+# A 3x3 matrix (no ties)
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+for (mode in c("integer", "double")) {
+  x <- matrix(c(1,2,3,2,3,4,3,4,5)+0.1, nrow=3, ncol=3)
+  cat("mode: ", mode, "\n", sep="")
+  storage.mode(x) <- mode
+  str(x)
+
+  cat("rowMads():\n")
+  r0 <- rowMads_R(x, na.rm=TRUE)
+  r1 <- rowMads(x, na.rm=TRUE)
+  r2 <- colMads(t(x), na.rm=TRUE)
+  stopifnot(all.equal(r1, r2))
+  stopifnot(all.equal(r1, r0))
+  stopifnot(all.equal(r2, r0))
+
+  cat("colMads():\n")
+  r0 <- colMads_R(x, na.rm=TRUE)
+  r1 <- colMads(x, na.rm=TRUE)
+  r2 <- rowMads(t(x), na.rm=TRUE)
+  stopifnot(all.equal(r1, r2))
+  stopifnot(all.equal(r1, r0))
+  stopifnot(all.equal(r2, r0))
+}
+
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Ties: a 4x4 matrix
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-x <- matrix(c(1:4,2:5,3:6,4:7), nrow=4, ncol=4)
-#x[2,2] <- NA_integer_
 for (mode in c("integer", "double")) {
+  x <- matrix(c(1:4,2:5,3:6,4:7)+0.1, nrow=4, ncol=4)
   cat("mode: ", mode, "\n", sep="")
   storage.mode(x) <- mode
   str(x)
@@ -42,10 +67,10 @@ for (mode in c("integer", "double")) {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # No ties: a 3x3 matrix with an NA value
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-x <- matrix(c(1,2,3,2,3,4,3,4,5), nrow=3, ncol=3)
-x[2,2] <- NA_real_
-
 for (mode in c("integer", "double")) {
+  x <- matrix(c(1,2,3,2,3,4,3,4,5)+0.1, nrow=3, ncol=3)
+  x[2,2] <- NA_real_
+
   cat("mode: ", mode, "\n", sep="")
   storage.mode(x) <- mode
   str(x)
