@@ -16,15 +16,41 @@ colVars_R <- function(x, na.rm=FALSE) {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # With and without some NAs
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-for (addNA in c(FALSE, TRUE)) {
-  cat("addNA=", addNA, "\n", sep="")
+for (mode in c("integer", "double")) {
+  for (addNA in c(FALSE, TRUE)) {
+    cat("addNA=", addNA, "\n", sep="")
+  
+    x <- matrix(1:100+0.1, nrow=20, ncol=5)
+    if (addNA) {
+      x[13:17,c(2,4)] <- NA_real_
+    }
+    cat("mode: ", mode, "\n", sep="")
+    storage.mode(x) <- mode 
+    str(x)
 
-  x <- matrix(1:100, nrow=20, ncol=5)
-  if (addNA) {
-    x[13:17,c(2,4)] <- NA_real_
-  }
+    # Row/column ranges
+    for (na.rm in c(FALSE, TRUE)) {
+      cat("na.rm=", na.rm, "\n", sep="")
+      r0 <- rowVars_R(x, na.rm=na.rm)
+      r1 <- rowVars(x, na.rm=na.rm)
+      r2 <- colVars(t(x), na.rm=na.rm)
+      stopifnot(all.equal(r1, r2))
+      stopifnot(all.equal(r1, r0))
+      stopifnot(all.equal(r2, r0))
+    }
+  } # for (addNA ...)
+}
+
+
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+# All NAs
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+for (mode in c("integer", "double")) {
+  x <- matrix(NA_real_, nrow=20, ncol=5)
+  cat("mode: ", mode, "\n", sep="")
+  storage.mode(x) <- mode 
+  str(x)
 
-  # Row/column ranges
   for (na.rm in c(FALSE, TRUE)) {
     cat("na.rm=", na.rm, "\n", sep="")
     r0 <- rowVars_R(x, na.rm=na.rm)
@@ -34,21 +60,6 @@ for (addNA in c(FALSE, TRUE)) {
     stopifnot(all.equal(r1, r0))
     stopifnot(all.equal(r2, r0))
   }
-} # for (addNA ...)
-
-
-# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# All NAs
-# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-x <- matrix(NA_real_, nrow=20, ncol=5)
-for (na.rm in c(FALSE, TRUE)) {
-  cat("na.rm=", na.rm, "\n", sep="")
-  r0 <- rowVars_R(x, na.rm=na.rm)
-  r1 <- rowVars(x, na.rm=na.rm)
-  r2 <- colVars(t(x), na.rm=na.rm)
-  stopifnot(all.equal(r1, r2))
-  stopifnot(all.equal(r1, r0))
-  stopifnot(all.equal(r2, r0))
 }
 
 
